@@ -14,7 +14,7 @@ from ldb.index.utils import (
     get_annotation_content,
 )
 from ldb.typing import JSONObject
-from ldb.utils import current_time, load_data_file
+from ldb.utils import DATA_OBJ_ID_PREFIX, current_time, load_data_file
 
 
 class AnnotationOnlyIndexer(Indexer):
@@ -24,6 +24,7 @@ class AnnotationOnlyIndexer(Indexer):
                 item = AnnotationOnlyIndexingItem(
                     self.ldb_dir,
                     current_time(),
+                    self.tags,
                     FileSystemPath(fs, path),
                 )
                 self.result.append(item.index_data())
@@ -57,6 +58,10 @@ class AnnotationOnlyIndexingItem(AnnotationFileIndexingItem):
             self.data_object_meta_file_path,
         )
         meta_content["last_indexed"] = self.current_timestamp
+        meta_content["tags"] = sorted(  # type: ignore[assignment]
+            set(meta_content["tags"])  # type: ignore[arg-type]
+            | set(self.tags),
+        )
         return meta_content
 
     @cached_property
@@ -66,13 +71,14 @@ class AnnotationOnlyIndexingItem(AnnotationFileIndexingItem):
     def index_data(self) -> IndexedObjectResult:
         if not self.data_object_dir.exists():
             raise DataObjectNotFoundError(
-                f"Data object not found: 0x{self.data_object_hash} "
+                "Data object not found: "
+                f"{DATA_OBJ_ID_PREFIX}{self.data_object_hash} "
                 f"(annotation_file_path={self.annotation_fsp.path!r})",
             )
 
         new_annotation = not self.annotation_meta_file_path.is_file()
+        self.enqueue_data(self.data_object_to_write())
         self.enqueue_data(self.annotation_to_write())
-
         self.write_data()
         return IndexedObjectResult(
             found_data_object=False,
