@@ -6,7 +6,7 @@ from ldb.add import process_args_for_ls
 from ldb.dataset import OpDef, apply_queries
 from ldb.path import InstanceDir
 from ldb.string_utils import left_truncate
-from ldb.utils import get_hash_path, load_data_file
+from ldb.utils import DATA_OBJ_ID_PREFIX, get_hash_path, load_data_file
 
 
 @dataclass
@@ -21,6 +21,7 @@ def ls(
     ldb_dir: Path,
     paths: Sequence[str],
     collection_ops: Iterable[OpDef],
+    warn: bool = True,
 ) -> List[DatasetListing]:
     data_object_hashes, annotation_hashes, _ = process_args_for_ls(
         ldb_dir,
@@ -31,6 +32,7 @@ def ls(
         data_object_hashes,
         annotation_hashes,
         collection_ops,
+        warn=warn,
     )
     return ls_collection(ldb_dir, collection)
 
@@ -51,7 +53,10 @@ def print_dataset_listings(
             if verbose
             else left_truncate(item.data_object_path)
         )
-        print(f"  0x{item.data_object_hash:35} {annotation_version:8} {path}")
+        print(
+            f"  {DATA_OBJ_ID_PREFIX}{item.data_object_hash:35} "
+            f"{annotation_version:8} {path}",
+        )
         num_items += 1
     return num_items
 
@@ -61,9 +66,10 @@ def ls_collection(
     collection: Iterable[Tuple[str, Optional[str]]],
 ) -> List[DatasetListing]:
     result = []
+    data_object_info_path = ldb_dir / InstanceDir.DATA_OBJECT_INFO
     for data_object_hash, annotation_hash in collection:
         data_object_dir = get_hash_path(
-            ldb_dir / InstanceDir.DATA_OBJECT_INFO,
+            data_object_info_path,
             data_object_hash,
         )
         annotation_version = 0
